==> haskell-sourcemap-0.1.6-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-BKuZkm5QWAz96SNalSJASS
key: sourcemap-0.1.6-BKuZkm5QWAz96SNalSJASS
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: 53f961699e434f1e08c33f4d7223ece5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-BKuZkm5QWAz96SNalSJASS
depends:
    aeson-0.11.2.0-1oWMNtvIfKMGa0C5QxOdH8
    attoparsec-0.13.0.2-4oqBQA8Yjg9Kon1ukf0gbT base-4.9.0.0
    bytestring-0.10.8.1 process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
key: sourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
license: BSD3
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
author: Chris Done
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
abi: 754ee8b7c08c5f6c53f737a31233add7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/sourcemap-0.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-Jx2eRW10tsVBm10lnQjnKJ
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM
    attoparsec-0.13.1.0-8poMzD5ooNXJ4NDLaelDWq base-4.9.0.0
    bytestring-0.10.8.1 process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
